@@ -3,7 +3,7 @@ package Config::Properties;
 use strict;
 use warnings;
 
-our $VERSION = '1.76';
+our $VERSION = '1.77';
 
 use IO::Handle;
 use Carp;
@@ -237,9 +237,17 @@ sub order {
 sub load {
     my ($self, $file) = @_;
     _t_file $file;
-    unless (grep /^(?:encoding|utf8)\b/, PerlIO::get_layers($file)) {
-        binmode $file, ":encoding($self->{encoding})"
-            or croak "Unable to set file encoding layer: $!";
+
+    # check whether it is a real file handle
+    my $fn = do {
+        local $@;
+        eval { fileno($file) }
+    };
+    if (defined $fn and $fn >0) {
+        unless (grep /^(?:encoding|utf8)\b/, PerlIO::get_layers($file)) {
+            binmode $file, ":encoding($self->{encoding})"
+                or croak "Unable to set file encoding layer: $!";
+        }
     }
     $self->{properties}={};
     $self->{property_line_numbers}={};
@@ -287,8 +295,8 @@ my $bomre = eval(q< qr/^\\x{FEFF}/ >) || qr//;
 sub process_line {
     my ($self, $file) = @_;
     my $line=<$file>;
-
     defined $line or return undef;
+    $line =~ s/\r\n/\n/g;
     my $ln = $self->{line_number} = $file->input_line_number;
     if ($ln == 1) {
         # remove utf8 byte order mark
@@ -602,9 +610,9 @@ java.util.Properties API.  It is designed to allow easy reading,
 writing and manipulation of Java-style property files.
 
 The format of a Java-style property file is that of a key-value pair
-seperated by either whitespace, the colon (:) character, or the equals
+separated by either whitespace, the colon (:) character, or the equals
 (=) character.  Whitespace before the key and on either side of the
-seperator is ignored.
+separator is ignored.
 
 Lines that begin with either a hash (#) or a bang (!) are considered
 comment lines and ignored.
@@ -681,7 +689,7 @@ Sets how to order the properties when saved to a file or when returned
 by C<properties> and C<propertyNames> methods.
 
 C<alpha> sorts the keys in alphanumeric order. C<keep> keeps the order
-of the properties as added or readed from a file. C<none> returns the
+of the properties as added or read from a file. C<none> returns the
 properties unordered.
 
 =item encoding => $encoding
@@ -807,7 +815,7 @@ makes...
 =item $p-E<gt>setFromTree($tree, $separator, $start)
 
 This method sets properties from a tree of Perl hashes and arrays. It
-is the opposite to splitToTree.
+is the opposite of C<splitToTree>.
 
 C<$separator> is the string used to join the parts of the property
 names. The default value is a dot (C<.>).
@@ -890,7 +898,7 @@ org.apache.commons.configuration.PropertiesConfiguration
 =head1 AUTHORS
 
 C<Config::Properties> was originally developed by Randy Jay Yarger. It
-was mantained for some time by Craig Manley and finally it passed
+was maintained for some time by Craig Manley and finally it passed
 hands to Salvador FandiE<ntilde>o <sfandino@yahoo.com>, the current
 maintainer.
 
